# geek_code

## Geek Code 6.x

# What Is Geek Code?
The Geek Code was developed in 1993 as a system of letters and symbols used by self-proclaimed "geeks" to provide information about their personality, appearance, interests, skills, and opinions to other geeks.

This code aims to offer a brief yet comprehensive depiction of one's self within the realm of geek culture. It covers key dimensions using a limited number of categories, which are further specified with qualifiers or quantifiers. The goal is to encode everything that defines a geek's individuality into a compact format that only other geeks can comprehend, which is thought to be an efficient approach within geek culture.

By sharing your geek code with friends and acquaintances, you can help them understand that today's geeks are the trendsetters of tomorrow.

Older Versions
------
Robert A. Hayden, a student and later a graduate of Mankato State University, created and wrote Version 0.1 of the Geek Code, which only had about five categories. Version 0.2 focused on correcting spelling and bugs, while Version 0.3 added a few more categories.

The web links provided in this text are some of the earliest examples of the Geek Code still surviving on the internet. In the case that these websites disappear or stop loading, a backup of the old code has been created for posterity in this GitHub repository.

[Click here to see Version 0.3 on the web!](https://www.cs.cmu.edu/afs/cs/user/scotts/ftp/bulgarians/geek-code.html "This is perhaps the oldest still surviving example of Geek Code on the web!")

Version 1.0 was released four months after 0.3, on July 17, 1993, and added several more categories, along with rules for cross-overs and variables.

[Click here to see Version 1.0.1 here!](http://www.textfiles.com/100/codegeek.txt)

Version 2.0 was released a year after Version 1.0, and at least 75 additions were included in that version, representing the recommendations of dozens of people. This milestone also signifies the moment when the geek code had expanded to such an extent that it ultimately needed to undergo revision in order to maintain internal coherence.

[Click here to see version 2.1 on the web!](http://www.aleph.se/Nada/nerdiness/geek2)

Version 3.x, which was released on March 5, 1996, was a significant refinement over Version 2.x, aimed at eliminating many of the non-geeky categories to make room for more geeky traits. Some of the odd categories that were removed in 3.x included automobiles, nutrition, and even Barney.

The geekcode Linux package, which is presently accessible on Debian and Ubuntu, operates on Version 3.12. However, it is imperative to note that this Linux package solely comprises the rudimentary form of the Version 3 Geek Code and is bereft of support for crossovers and variables.

[Version 3.1](https://web.archive.org/web/20090220181018/http://geekcode.com/geek.html)

[Version 3.1 Generator](https://www.joereiss.net/geek/geek.html)

[Version 3.1 Decoder](http://www.ebb.org/ungeek/ "Real geeks shouldn't need this though.")

Version 4.x was released on GitHub on October 18, 2019, with some categories removed, added, and altered.

[Click here to see Version 4.0!](https://github.com/telavivmakers/geek_code/blob/8903d925d6660d9afa661d6cb99f13976d95242f/README.md)

Version 5.0 eliminated case-sensitive categories and modified some letters and categories. The latest versions of the Geek Code are aimed at giving geeks a better platform to express their interests.


Welcome to The Geek Code Version 6.0
======

This updated edition has been revised by ChatGPT, who has improved the language for better comprehension, flow, and enriched vocabulary. Additionally, all spelling, grammar, and punctuation mistakes have been rectified.

Although the original content remains unaltered, we classify this as a fresh rendition, as the alterations made to the text were significant, and the modern AI approach taken to refine it is unique from previous versions.


How Does It Work?
------

The code is made up of alphanumeric identifiers that represent different categories and subcategories. Following these identifiers are qualifiers, represented by the symbols + and -, that indicate factors such as amount, size, or level of proficiency. These qualifiers can be stacked to provide more specific information, such as `H+++`, which indicates an individual with an extremely high level of skill in Hardware.

The broad categories that can be encoded are: Geek of, Wetware, Computers, Politics, Entertainment, and Lifestyle. Each category has its own subcategories, and you can provide as much or as little detail as you like. For example, `U++` indicates a person with a high level of interest or proficiency in Unix, while `ULDU++` indicates someone with a particular interest in Unix/Linux/Debian/Ubuntu. Additional subcategories can be indicated with a forward slash, such as `GCS/GM`, which indicates a Geek of Computer Science and Math.

Some categories may not be relevant to you, so you can ignore them. Also, some of the qualifiers may not be a perfect match for your level of proficiency or interest, so choose the qualifier that most closely reflects your abilities.

Once you have provided a set of category/qualifier strings for any of the above, it's time to assemble your code for display. Simply concatenate the substrings with a space between them. Your final code might look something like this:

```
GCS^/GM^ A++(a?) B_:--:+:-:+ C++(C-) D+:+ CM++(++++) MW11+++@ ULD++++$ MC-- Lbash+++/LC#+/Lj+/Lpy++/Lvb IO+++:---(+) G:exarobibliologist E++ H+ PGP PSG PE TDW+/TEX+++/THRO++++/TMON+++/TOB+++/TSTsnw+++/TSTld+++/TSTdsc-- RPG+++(*)>$ BK+++ KX+++ INTJ-A R-- he/him+++
```

When it comes to sharing code, using a long line can be unwieldy and difficult to read for the user. To improve the readability, it's advisable to incorporate line breaks in between certain categories. This approach can help create a rough box shape that makes the code more accessible and easier to follow.

```
-----	BEGIN GEEK CODE VERSION 6.0	-----
GCS^/GM^ A++(a?) B_:--:+:-:+ C++(C-) D+:+ CM++(++++)
MW11+++@ ULD++++$ MC-- Lbash+++/LC#+/Lj+/Lpy++/Lvb
IO+++:---(+) G:exarobibliologist E++ H+ PGP PSG PE
TDW+/TEX+++/THRO++++/TMON+++/TOB+++/TSTsnw+++/TSTld+++/
TSTdsc-- RPG+++(*)>$ BK+++ KX+++ INTJ-A R-- he/him+++
-----	END GEEK CODE VERSION 6.0	-----
```

Special characters
------

A few special characters allow for the (ultimately wrong but practically useful) notion that geeks can seldom be strictly quantified.

|			|			|				|
|:---		|	:---:	|	:---		|
|	`+`		|	=		|	Indicates a higher level of geekiness in a specific area. Each additional + raises the level further.	|
|	`_`		|	=		|	(Optional) Indicates a baseline answer. _ is one step above -, and one step below +. Therefore, _ is never combined with + or -. For example, instead of leaving it blank/empty, a geek of average shape and size could write `d_:_` to indicate they are at the baseline.	|
|	`-`		|	=		|	Indicates a lower level of geekiness in a specific area. Each additional - reduces the level further.	|
|	`@`		|	=		|	Indicates a trait that is not very rigid and may change with time or with individual interaction. For example, Geeks who happen to enjoy Star Trek: Picard as a whole, but aren't sure how they like the current season might list themselves as `TSTpic+++@`.	|
|	`()`	|	=		|	Indicates "cross-overs" or ranges. Geeks who go from C+ to C- depending on the situation (i.e. mostly "C+") could use `C+(-)`. Note: @ is different from () in that () has finite limits within the category, while @ ranges all over.	|
|	`$`		|	=		|	Indicates that this particular category is something a geek earns money by doing. For example, `UL+++$` indicates that the person utilizes Unix and gets paid for it.	|
|	`^`		|	=		|	Indicates that the geek has a degree or certificate in this area or field. For example, `GCS^/GMU/GTW^` indicates that this is a Geek of Computer Science (possessing a degree), a Geek of Music, and a Geek of Technical Writing (with a certificate here)	|
|	`>`		|	=		|	Indicates a goal. Indicating that while the geek is currently at one rating, they are striving to reach another. For example, `UL+++>$` indicates a geek that is currently Linux savvy but wants to someday make money at it.	|
|	`?`		|	=		|	Unless stated otherwise within the specific category, the ? is placed after the category identifier and indicates that the geek has no knowledge about that specific category.	|
|	`!`		|	=		|	Placed BEFORE the category. Unless stated otherwise, indicates that the person refuses to participate in this category. This is unlike the ? variable as the ? indicates a lack of knowledge, while the ! indicates stubborn refusal to participate. For example, `!MC` would be a person that refuses to have anything to do with Macintosh, while `MC?` would be a person that doesn't even know what Macintosh is.	|

The categories
======

G = GEEK OF - training/degree/interest/job
======

In order for a person to commence coding, they must first identify themselves as a geek. This is achieved by beginning the code with a "G" which stands for "GEEK", followed by one or two letters that indicate the geek's profession or area of expertise. Geeks who possess multiple skill sets in various vocations should utilize a slash to distinguish each of their talents (e.g., GCS/MU/TW) and showcase their multifaceted abilities.

|				|			|				|
|:---			|	:---:	|	:---		|
|	`GAI`		|	=		|	Geek of Artificial Intelligence 	|
|	`GBIO`		|	=		|	Geek of Biomedical Engineering		|
|	`GB`		|	=		|	Geek of Business					|
|	`GC`		|	=		|	Geek of Classics					|
|	`GCA`		|	=		|	Geek of Commercial Arts				|
|	`GCM`		|	=		|	Geek of Computer Management			|
|	`GCS`		|	=		|	Geek of Computer Science			|
|	`GCC`		|	=		|	Geek of Communications				|
|	`GDS`		|	=		|	Geek of Data Science				|
|	`GDVO`		|	=		|	Geek of DevOps						|
|	`GE`		|	=		|	Geek of Engineering					|
|	`GED`		|	=		|	Geek of Education					|
|	`GFA`		|	=		|	Geek of Fine Arts					|
|	`GFS`		|	=		|	Geek of Forensic Science			|
|	`GG`		|	=		|	Geek of Government					|
|	`GH`		|	=		|	Geek of Humanities					|
|	`GIT`		|	=		|	Geek of Information Technology		|
|	`GJ`		|	=		|	Geek of Jurisprudence (Law)			|
|	`GLS`		|	=		|	Geek of Library Science				|
|	`GL` 		|	=		|	Geek of Literature					|
|	`GMC` 		|	=		|	Geek of Mass Communications			|
|	`GM`		|	=		|	Geek of Math						|
|	`GMD` 		|	=		|	Geek of Medicine					|
|	`GMU`		|	=		|	Geek of Music						|
|	`GPA` 		|	=		|	Geek of Performing Arts				|
|	`GP` 		|	=		|	Geek of Philosophy					|
|	`GS`		|	=		|	Geek of Science						|
|	`GSS` 		|	=		|	Geek of Social Science				|
|	`GTW`		|	=		|	Geek of Technical Writing			|
|	`GVGD`		|	=		|	Geek of Video Game Design			|
|	`GO` 		|	=		|	Geek of Other. Some types of geeks deviate from normal geek activities.	This is encouraged as true geeks come from all walks of life.	|
|	`GU`		|	=		|	Geek of 'Undecided'. This is a popular vocation with incoming freshmen.	|
|	`G!`		|	=		|	Geek of no qualifications nor interests; likely, cannot exist	|
|	`GAT`		|	=		|	Geek of All Trades. For those geeks that can do anything and everything. GAT usually precludes the use of other vocational descriptors.	|


WETWARE (A,B,C,D) (age/beard/clothing/dimensions)
======

It is often said that first impressions are crucial and can never be undone. However, The Geek holds a different opinion. As per an ancient meme, "on the internet, it's impossible to distinguish a person from a dog". Despite that, this section provides an opportunity to disclose information about one's appearance, possibly for dating reasons or other trivial matters. Moreover, it enables us to kickstart with the basics, denoting age, beard, clothing, and dimensions using the abbreviations 'ABCD.'

A = Age
------

The only way to become a true geek is through practice and experience. To this end, your age becomes an important part of your geekiness. Employ the following descriptions to indicate your age in Terran years, using a base 10 system, of course.

|				|			|				|
|:---			|	:---:	|	:---		|
|	`A++++`		|	=		|	60+			|
|	`A+++`		|	=		|	50-59		|
|	`A++`		|	=		|	40-49		|
|	`A+`		|	=		|	30-39		|
|	`A`			|	=		|	25-29		|
|	`A-`		|	=		|	20-24		|
|	`A--`		|	=		|	15-19		|
|	`A---`		|	=		|	10-14		|
|	`A----`		|	=		|	9 and under (Geek in training?)	|
|	`A?`		|	=		|	immortal?	|
|	`!A`		|	=		|	it's none of your business how old I am	|
|	`A=##`		|	=		|	Share your exact age by placing a number after. For example: A=42	|

B = Beardliness/Hair
------

Facial hair has a significant presence in the geek community, serving as a means of expressing one's personal style and countercultural leanings. Although the concept of ["unix beards"](http://www.usenix.org.uk/content/unix_beards.html) may not apply to everyone, it still deserves recognition and inclusion in this category.

The hair code is divided into five distinct parts, each separated by a colon.

These parts are ( `Head : Beard : Brows : Mustache : Sideburns` )

|				|			|				|
|:---			|	:---:	|	:---		|
|	`+++`		|	=		|	At times, onlookers may perceive me as a Sasquatch due to the excessive amount of hair I possess	|
|	`++`		|	=		|	Good hair growth!	|
|	`+`			|	=		|	Above average hair growth	|
|				|	=		|	Average	|
|	`-`			|	=		|	Less than normal, partially shaved	|
|	`--`		|	=		|	Bald / Shaved	|
|	`---`		|	=		|	Alopecia / Unable to grow hair there	|

Thus `B_:++:+:++:_` means that geek has an average head of hair, with an impressive beard, thick brows, an equally impressive mustachio, and ordinary sideburns.


C = Clothing
------

|				|			|				|
|:---			|	:---:	|	:---		|
|	`C++`		|	=		|	I have a tendency to opt for more traditional and formal attire, such as a sharp business suit, and on occasion, I may even wear a tie.	|
|	`C+` 		|	=		|	Appropriate attire for leisure activities includes slacks and a button-up shirt, among other options. Jeans, tennis shoes, and t-shirts should be avoided.	|
|	`C`			|	=		|	My wardrobe bears a striking resemblance to those depicted in catalog advertisements. The pieces lack any unique characteristics, are uninteresting, and fail to convey a sense of purpose or individuality.	|
|	`C-`		| 	=		|	My typical attire consists of jeans and a comfortable t-shirt.	|
|	`C--`		|	=		|	My t-shirts are not just ordinary pieces of clothing. They boast a stylish political message, making them all the more unique and fashionable.	|
|	`C---`		|	=		|	My punk fashion style can encompass a variety of elements such as distressed denim pants and tops, as well as body adornments like piercings and bold tattoos.	|
|	`Cx`		|	=		|	Cross Dresser	|
|	`C?`		|	=		|	I have no idea what I am wearing right now, let alone what I wore yesterday.	|
|	`!C`		|	=		|	No clothing. Quite a fashion statement, don't you think?	|
|	`Cpu`		|	=		|	I have a tendency to wear the exact same attire consistently, disregarding the type of event or activity I'm attending. This is mainly due to my forgetfulness in washing my garments in between wearings.	|

D = Dimensions
------

People who are considered geeks come in a wide variety of forms. The initial portion indicates the vertical extent, while the latter represents the horizontal extent. The two parts are delimited by a colon.

|				|			|	Vertical Extent		|	Horizontal Extent	|
|:---			|	:---:	|	:---				|	:---				|
|	`+++:+++` 	|	=		|	My height requires me to duck through doors.		|	My broad build takes up the space of three cinema seats.		|
|	`++:++` 	|	=		|	I have the physical build of a basketball player.	|	I have the physical build of a linebacker.		|
|	`+:+` 		|	=		|	I am slightly taller than the average person.		|	I have a rounder body shape than most others.	|
|	`:` 		|	=		|	Geek of average height							|	Geek of average width			|
|	`-:-`		|	=		|	I am shorter than most individuals.				|	People frequently advise me to gain weight.	|
|	`--:--` 	|	=		|	I am significantly shorter than most people.	|	I often have to push through strong winds due to my lean build.	|
|	`---:---` 	|	=		|	I require a phone book to elevate myself during meals. 	|	My body is emaciated and bony.	|

Example: `D+++:---` indicates extremely tall and thin.

CM = COMPUTERS
======

It is a known fact that there existed a group of individuals who were classified as geeks, but surprisingly they did not use computers. However, their era was devoid of such technology, and unfortunately, they are all no longer alive.

In this day and age, it is expected that geeks have some level of familiarity with computers. If, for some reason, you have no idea what a computer is, it's high time you acquaint yourself with the technology.

For many geeks, their identity is closely tied to their proficiency in using computers and computer networks. To evaluate your level of geekiness when it comes to computers, consult the following guide. This first category will serve as a general indicator of your computer aptitude, while the subsequent categories delve into more specific areas.

|				|			|				|
|:---			|	:---:	|	:---		|
|	`CM++++` 	|	=		|	I want to be the first in line to have the cutting-edge cybernetic interface implanted into my body.	|
|	`CM+++`		|	=		|	"Are you telling me that there's more to life than just being online? It's been weeks since I last logged out. I've been spending my time on StackOverflow, providing answers to various questions."	|
|	`CM++` 		|	=		|	As someone who has embraced the digital age, computers are an integral component of my everyday life. I am adept at coding in at least one programming language and frequently refer to StackOverflow to resolve any technical queries that I encounter.	|
|	`CM+`		|	=		|	I find computers to be entertaining and fun to use. Furthermore, I possess enough knowledge that when prompted with the instruction 'press any key to continue', I need not scour the keyboard in search of a specific key labeled 'ANY'.	|
|	`CM`		|	=		|	Computers are a mere instrument, devoid of any intrinsic value. I resort to its employment solely when it is conducive to accomplishing my goals.	|
|	`CM-`		|	=		|	If I encounter anything that goes beyond the capabilities of my calculator, I am in serious trouble.	|
|	`CM--`		|	=		|	Where's the on switch?	|
|	`CM---`		|	=		|	"Computers? No thank you. Aren't those the devices possessed by demons?"	|

MW = Microsoft Windows
------

A good many geeks suffer through the use of various versions of Microsoft Windows.

Let us know the extent of your expertise by rating your level of "Windows geekiness". Feel free to include the versions of Windows you have had experience with, or are currently utilizing. To give an example, a rating of `MW11+++` indicates that you possess exceptional proficiency in using Windows 11.
|				|			|				|
|:---			|	:---:	|	:---		|
|	`MW++++`	|	=		|	As an expert in MS Windows programming, I have successfully crafted and compiled more than one executable file (.exe), installation package (.msi), or dynamic link library (.dll). My proficiency in this field is unparalleled, and I take pride in my ability to deliver top-notch results.	|
|	`MW+++`		|	=		|	I specialize in compiling code for Microsoft platforms.	|
|	`MW++`		|	=		|	I have utilized my knowledge of Windows REGEDIT to bypass security protocols and remedy a number of glitches on my personal computer. Some people think I'm a hacker.	|
|	`MW+`		|	=		|	My computer is an ultimate expression of my personal style, with customized sounds, wallpapers, and screen savers that bring the fun house to my desktop. I've even gone as far as installing an impressive array of a hundred fonts, though I've yet to find the perfect opportunity to use them.	|
|	`MW`		|	=		|	Although I utilize Windows solely for a particular reason such as playing games on Steam, I must admit that I do not necessarily enjoy its use.	|
|	`MW-`		|	=		|	I'm always have trouble installing MS Windows on my device, and frequently I face issues with one of my peripherals that does not function properly.	|
|	`MW--`		|	=		|	MS Windows is a joke operating system. No one can find the error codes anymore, and even if they could no one can read hexadecimal to understand them!	|
|	`MW---`		|	=		|	Windows has set back the computing industry by at least 10 years. Bill Gates should be drawn, quartered, hung, shot, poisoned, disemboweled, and then REALLY hurt.	|

U = Unix
------

It appears that most tech enthusiasts prefer a Unix-based operating system. In order to showcase your proficiency with Unix, it is helpful to identify the specific Unix OS that you utilize. This can be done by incorporating a letter in your rating that denotes the brand. As an example, `UL++++` signifies that you are a system administrator operating on Linux.

````
	U = Unix
		UL = Linux
			ULA = Arch
				ULAP = Pacman
			ULD = Debian
				ULDU = ubuntu
					ULDUM = Linux Mint
					ULDU* = 3rd party/discontinued ubuntu
				ULDD = Deepin
			ULF = Fedora
			ULRH = Red Hat Enterprise Linux
				ULRC = Centos
				ULRO = OpenSUSE
			ULG = Gentoo
				ULGC = ChromeOS / ChromiumOS
			ULS = Slackware
			UL* = other
		US = Sun OS/Solaris
		UA = AIX
		UH = HPUX
		UI = IRIX
		UC = SCO Unix
	U* = Some other one not listed
````
some examples

|				|			|				|
|:---			|	:---:	|	:---		|
|	`U++++`		|	=		|	I am the sysadmin. I caution against attempting to breach the security of my computer. If you do, don't be shocked if the municipal works department receives an "unintentional" computer-generated request to commence construction on a new landfill on your property.	|
|	`U+++`		|	=		|	There's no need for me to crack into /etc/passwd since I've made a modification to su that eliminates the need for a prompt. As a result, the admin staff is unaware of my presence.	|
|	`U++`		|	=		|	I have managed to annoy the entire administration as a result of my constant utilization of all the CPU time and attempts to run programs that are beyond my authorized access.	|
|	`U+`		|	=		|	I enjoy shell scripting and understand the fundamental importance of the difference between ' and `	|
|	`U`			|	=		|	I have a Unix account to do my stuff in	|
|	`U-`		|	=		|	I have a VMS account.	|
|	`U--`		|	=		|	I've seen Unix and didn't like it. DEC rules!	|
|	`U---`		|	=		|	Unix geeks are actually nerds in disguise.	|

MC = Mac/Apple
------

Numerous technology enthusiasts have made the switch from personal computers to Apple products. Kindly inform us of your Mac rating.

|				|			|				|
|:---			|	:---:	|	:---		|
|	`MC++`		|	=		|	As a highly skilled Mac expert, I possess a vast array of knowledge and capabilities. I am confident in my ability to outperform those individuals who specialize in other operating systems such as DOS or Unix. Even in cases where I may not have immediate expertise, I possess the skills and ingenuity necessary to create the software required to accomplish any task.	|
|	`MC+`		|	=		|	A Mac serves various purposes, and I frequently utilize it in my daily activities.	|
|	`MC` 		|	=		|	Although I utilize a Mac, my feelings towards it are relatively ambivalent.	|
|	`MC-` 		|	=		|	Macs are inferior. True technology enthusiasts only use a command line interface, or a character prompt, for their computing needs.	|
|	`MC--`		| 	= 		|	Macs do more than suck. They make a user stupid by allowing them to use the system without knowing what they are doing. Mac weenies have lower IQs than the fuzz in my navel.	|

L = Programming Languages
------

List a series of languages and your facility/opinion thereupon, for example, `Lpy++/LR+` would indicate high proficiency in python and above-average knowledge of R.

|				|			|				|
|:---			|	:---:	|	:---		|
|	`Lasm` 		|	=		|	Assembly			|
|	`Lbash`		|	=		|	Bourne Again Shell	|
|	`LC`		|	=		|	C programming lang	|
|	`LCpp`		|	=		|	C plus plus			|
|	`LC#`		|	=		|	C sharp				|
|	`Lgo` 		|	=		|	Go					|
|	`LGPT` 		|	=		|	GPT					|
|	`Lj`		|	=		|	Java				|
|	`Ljs`		|	=		|	Javascript			|
|	`Llll`		|	=		|	Low-level Lisp		|
|	`Llua`		|	=		|	Lua					|
|	`LM` 		|	=		|	MATLAB				|
|	`LoC` 		|	=		|	Objective C			|
|	`LP` 		|	=		|	Perl				|
|	`Lphp`		|	=		|	PHP					|
|	`Lpy`		|	=		|	Python				|
|	`LQ#`		|	=		|	Q sharp				|
|	`LR` 		|	=		|	R					|
|	`LRs`		|	=		|	Rust				|
|	`LRu`		|	=		|	Ruby				|
|	`Lsql` 		|	=		|	SQL					|
|	`Lvb`		|	=		|	Visual Basic		|
|	`Lwps`		|	=		|	Windows PowerShell	|

For example:

|				|			|				|
|:---			|	:---:	|	:---		|
|	`Lpy+++`	|	=		|	I am Guido van Rossum	|
|	`Lpy++`		|	=		|	I maintain and provide contributions  to the Python code base.	|
|	`Lpy+`		|	=		|	As a devoted Python enthusiast, I consistently utilize this programming language in my work. I take pride in aligning my statements with the principles of "pythonic" coding.	|
|	`Lpy`		|	=		|	I am neutral towards Python; it is decent for certain purposes.	|
|	`Lpy-`		|	=		|	Python is a programming language for hobbiests	|
|	`Lpy--` 	|	=		|	I hold a strong aversion towards python; it appears to be an unsightly deviation that only caters to those who are unable to comprehend the intricate capabilities of [C|Lisp|assembly].	|


IO = Input/Output
------

How do you go about handling your data? And, once you have it, how do you effectively communicate it to others? Input/Output, consisting of two distinct sections separated by a colon, determines just how easily you are able to navigate and make sense of your data.

|			|			|	Input		|		Output		|
|:---		|	:---:	|	:---		| 	:---			|
|	`+++`	|	=		|	I wrote my own database system as current performance limitations were irking me	|	I am a java bean 	|
|	`++`	|	=		|				|					|
|	`+`		|	=		|				|					|
|			|	=		|	Uses mouse and keyboard equally	|	Uses mouse and keyboard equally	|
|	`-`		|	=		|				|					|
|	`--`	|	=		|				|	My user interface is a text-only Terminal. Don't even touch the mouse	|
|	`---`	|	=		|	Keep the data and code out of sight. I focus on creating an attractive graphical user interface for maximum impact.	|	The concept of 'user experience' holds no significance to me. In my view, users can be effectively studied and understood through Bayesian techniques.	|

For example: `IO+++:---` indicates that you will be dealing with data in its most unprocessed form, both in receiving and transmitting it.


PGP
------

Pretty Good Privacy (aka PGP) is a program available on many platforms that will encrypt files so that prying eyes (particularly governmental) can't look at them.

|				|			|				|
|:---			|	:---:	|	:---		|
|	`PGP++++`	| 	=		|	My name is Philip Zimmerman and/or I am a strong advocate for PGP.	|
|	`PGP+++`	| 	=		|	For security reasons, I exclusively communicate through encrypted or signed mail. If you're able to read this without decrypting it first, there's a problem as it didn't come from me.	|
|	`PGP++`		|	=		|	As a PGP user, I stay up to date with the latest version and regularly implement it.	|
|	`PGP+`		|	=		|	Please "finger" me for my public key.	|
|	`PGP`		|	=		|	I used PGP before, but I haven't utilized it in a long time.	|
|	`PGP-`		|	=		|	I don't feel the need to use encryption as I don't have anything to hide.	|
|	`PGP--`		|	=		|	Although I recognize the importance of encryption, I believe that the true value of the internet lies in its open and free exchange of information. Encryption can sometimes inhibit that.	|
|	`PGP---`	|	=		|	If you are in support of encryption on the internet, it's possible that people may assume you're involved in illegal activities like drug dealing or terrorism.	|
|	`PGP----`	|	=		|	Instead of PGP, I recommend using (insert Clipper here) which I believe is a better alternative.	|

G = GitHub Username
------

Version control systems are indispensable for programmers and technology enthusiasts alike. Please kindly share with us the name of the version control system that you prefer to use, along with your corresponding username. This will enable us to easily locate you and connect with you.

|				|			|				|
|:---			|	:---:	|	:---		|
|	`G`			|	=		|	GitHub		|
|	`Gl`		|	=		|	GitLab		|
|	`Gb`		|	=		|	BitBucket	|
|	`Gbk`		|	=		|	Bitkeeper	|
|	`Gbn`		|	=		|	Beanstalk	|
|	`Gsvn`		|	=		|	Subversion	|
|	`Gtfs`		|	= 		|	Team Foundation Server	|

Write your username, after the code, like the following examples:

```
G:exarobibliologist
Gbn:rutman
```

E = Electronics
------

|				|			|				|
|:---			|	:---:	|	:---		|
|	`E+++`		|	=		|	I am as skilled as Lady Ada Lovelace, the first computer programmer.	|
|	`E++`		|	=		|	Thanks to my skill and need for efficiency, I have successfully repaired malfunctioning toasters without unplugging them. 	|
|	`E+`		|	=		|	I am familiar with the concepts of CMOS and BJT, as well as the important distinction between a comparator and an operational amplifier (op amp).	|
|	`E`			|	=		|				|
|	`E-`		|	=		|				|
|	`E--`		|	=		|	Electrons are interesting as theoretical constructs	|

H = Hardware
------

|				|			|				|
|:---			|	:---:	|	:---		|
|	`H+++`		|	=		|	I am as skilled as Charles Babbage, the father of the mechanical computer.	|
|	`H++`		|	=		|	I crafted my very own chainmail armor by smelting iron derived from ore mined through the utilization of steam-powered machinery I ingeniously fashioned from recycled car parts.			|
|	`H+`		|	=		|				|
|	`H`			|	=		|				|
|	`H-`		|	=		|	Metaphorically speaking, I have employed hammers on numerous occasions, whereas in reality, I have rarely utilized them.	|
|	`H--`		|	=		|	When there are issues with the hardware of my laptop, I find it preferable to bring it to a repair shop.	|

POLITICS
======

The last few years have seen the rise of the political geek. This phenomenon is little understood, but some theorize that it has come about because of the popular media's attempts to demonize the Internet and computer use in general, and the government's willingness to go along with it. Others propose that the aging geek population has simply started taking an interest in the world around them. Some support the "Sun Spot" theory.

Politics and Social Issues
------

Where, in general, your political views on different social issues fall. The + and – ratings here roughly indicate left/right on the political spectrum.

Subcategories (give yourself a geek point if your first thought was 'actually, subsubcategories') As of v4 some new subcategories are added to the PS and PE categories.

```
	PSG = green politics/sustainability/climate
	PSL = civil liberties
	PSS = gender politics
```

|				|			|				|
|:---			|	:---:	|	:---		|
|	`PS+++`		|	=		|	Advocate for the legalization of drugs! Call for the abolition of the government. "Fuck the draft!"	|
|	`PS++`		|	=		|	I contribute to organizations that champion liberal causes, including those focused on civil and gay rights, and strive to promote social justice. As an active member of the ACLU and/or NAACP, I am committed to supporting these critical initiatives. #BlackLivesMatter	#RoeVWade	|
|	`PS+`		|	=		|	Individuals should not impose their opinions or beliefs on others, regardless of their political stance. If something is not to your liking, you have the freedom to change the channel or simply walk away.	|
|	`PS`		|	=		|	At the present moment, my personal stance remains neutral as there are no perceived infringements on my liberties.	|
|	`PS-`		|	=		|	Prevent inappropriate content from appearing on the television and online platforms. It is imperative to establish a reliable and efficient rating system for music and online media.	|
|	`PS--`		|	=		|	I am in opposition to the idea of providing sex education, granting abortion rights, and recognizing gay rights.	|
|	`PS---`		|	=		|	Repent left-wing sinners and change your wicked evil ways. Make America great again!	|


Politics and Economic Issues
------
Note this category has been reversed as of v4 to maintain the loose left+ and right- association from the PS category.

|				|			|				|
|:---			|	:---:	|	:---		|
|	`PE+++`		|	=		|	Capitalism is evil! Essential services must be provided by the government. Nobody should be rich.	|
|	`PE++`		|	=		|	It is imperative to prevent the government from unnecessarily interfering with businesses. Therefore, it is highly recommended to reduce regulations and bureaucracy as much as feasible.	|
|	`PE+`		|	=		|		|
|	`PE`		|	=		|	I am skeptical towards both the government and businesses.	|
|	`PE-`		|	=		|	It is justifiable to augment government expenditure in order to aid a greater number of impoverished individuals. Reducing the allocation of funds towards defense, and levying taxes on the wealthy is imperative.	|
|	`PE--`		|	=		|	Attaining a balanced budget requires a meticulous examination of all expenditures, followed by astute reduction of costs, along with the implementation of an amendment. By doing so, financial stability can ultimately be reached.	|
|	`PE---`		|	=		|	Repeal the antitrust laws and implement a taxation system that favors the wealthy, allowing for a trickle-down effect to the rest of society.	|

ENTERTAINMENT
======

Enthusiastic and dedicated, geeks are known for their deep-seated interests and their enthusiasm for recreational pursuits. Regardless of age, they are drawn to the pleasures of playing, be it through board games, video games, or any other activity. What drives their passion for these hobbies? Is it a desire to recapture their youth or a natural proclivity towards mental stimulation?

T = TV
------

What are your thoughts on the TV show that captivates you as a devoted fan.

|	 			|			|						|
|:---			|	:---:	|	:---		|
|	`TBBT`		|	=		|	The Big Bang Theory	|
|	`TB5`		|	=		|	Babylon5			|
|	`TBG`		|	=		|	Battlestar Galactica			|
|	`TDW`		|	=		|	Doctor Who			|
|	`TEX`		|	=		|	The Expanse			|
|	`TFF`		|	=		|	Firefly				|
|	`TGT`		|	=		|	Game of Thrones		|
|	`TIL`		|	=		|	'In Search Of...' with Leonard Nimoy	|
|	`TMON`		|	=		|	Monty Python (series/films)	|
|	`TMM`		|	=		|	Mad Max	|
|	`TLOTR`		|	=		|	Lord of the Rings	|
|	`TL`		|	=		|	Lost	|
|	`TOB`		|	=		|	Orphan Black	|
|	`TRM`		|	=		|	rick&MORTY	|
|	`TW13`		|	=		|	Warehouse 13	|

### Heroes
|				|			|				|
|:---			|	:---:	|	:---		|
|	`THRO`		|	=		|	Heroes			|
|	`THROrb`	|	=		|	Heroes Reborn	|

### Leverage
|			|			|				|
|:---		|	:---:	|	:---		|
|	`TLV`	|	=		|	Leverage				|
|	`TLVr`	|	=		|	Leverage: Redemption	|

### Stargate
|			|			|				|
|:---		|	:---:	|	:---		|
|	`TSG`	|	=		|	Stargate	|
|	`TSG1`	|	=		|	Stargate SG-1	|
|	`TSGa`	|	=		|	Stargate Atlantis	|
|	`TSGu`	|	=		|	Stargate Universe	|
|	`TSGoc`	|	=		|	Stargate Origins Catherine	|

### Star Trek
|				|			|				|
|:---			|	:---:	|	:---		|
|	`TST`		|	=		|	Star Trek	|
|	`TSTanm`	|	=		|	Star Trek - Animated Series	|
|	`TSTng`		|	=		|	Star Trek - The Next Generation	|
|	`TSTds9`	|	=		|	Star Trek - Deep Space Nine	|
|	`TSTv`		|	=		|	Star Trek - Voyager	|
|	`TSTe`		|	=		|	Star Trek - Enterprise	|
|	`TSTdsc`	|	=		|	Star Trek - Discovery	|
|	`TSTpic`	|	=		|	Star Trek - Picard	|
|	`TSTld`		|	=		|	Star Trek - Lower Decks	|
|	`TSTst`		|	=		|	Star Trek - Short Treks	|
|	`TSTpro`	|	=		|	Star Trek - Prodigy	|
|	`TSTsnw`	|	=		|	Star Trek - Strange New Worlds	|

### Star Wars
|				|			|				|
|:---			|	:---:	|	:---		|
|	`TSW`		|	=		|	Star Wars	|
|	`TSWcw`		|	=		|	Star Wars Clone Wars	|
|	`TSWman`	|	=		|	The Mandalorian	|
|	`TSWand`	|	=		|	Star Wars - Andor	|
|	`TSWobi`	|	=		|	Star Wars - Obi-Wan Kenobi	|
|	`TSWbob`	|	=		|	Star Wars - Book of Boba Fett	|
|	`TSWv`		|	=		|	Star Wars - Visions	|
|	`TSWbb`		|	=		|	Star Wars - The Bad Batch	|
|	`TSWres`	|	=		|	Star Wars - Resistance	|
|	`TSWreb`	|	=		|	Star Wars - Rebels	|

Example Star Trek info
|				|			|				|
|:---			|	:---:	|	:---		|
|	`TST+++`	|	=		|	This is not merely a program on television, but rather a way of life. My knowledge extends beyond the characters and plot, encompassing the complexities of warp field dynamics and the underlying principles of the transporter. I have even committed the TECH manual to memory. In addition, I am fluent in the Klingon language and have been known to attend conventions adorned with Vulcan ears. My devotion to this universe leaves little room for any other pursuits.	|
|	`TST++`		|	=		|	This show is simply unbeatable. I possess all of the episodes and movies on VCR/DVD/Blu-Ray and can even recite entire scenes flawlessly. Furthermore, I've even constructed several of the model kits. However, I wouldn't be caught dead attending one of those conventions. Frankly, those individuals are a bit eccentric.	|
|	`TST+`		|	=		|	This is an exceptional television program that stands out as one of the few things worth watching on television these days.	|
|	`TST`		|	=		|	"Ah, it's merely another television program."	|
|	`TST-`		|	=		|	I fail to comprehend the immense popularity of Star Trek. Maybe there is something I am overlooking, but I simply find it to be uninteresting and lacking in quality drama.	|
|	`TST--`		|	=		|	Star Trek is merely another example of the Space Opera genre. I do not believe that William Shatner is a talented actor; rather, I view him as poser. Additionally, I find it strange that Jean-Luc Picard, a French character, has a British accent. Furthermore, I can't help but think that Voyager is just a recycled version of Lost in Space. In regards to Sisko, it appears as if he has hardly taken a breath in the past two seasons. Frankly, I wouldn't bother watching this show unless my remote control stopped working.	|
|	`TST---`	|	=		|	I have a strong dislike for Star Trek, as I find it to be of low quality. I would only go to conventions to urge fans of the show to prioritize their time on more meaningful pursuits.	|


RPG = Roleplaying
------

Role-playing games, such as Dungeons & Dragons, have been a popular pastime among geeks for quite some time. However, it is not uncommon for individuals who engage in role-playing to become so engrossed in their fantasy world that they lose sight of reality. Rank your ability with roleplaying games with the following code.

|				|			|				|
|:---			|	:---:	|	:---		|
|	`RPG+++`	|	=		|	I have authored and successfully published my very own gaming resources.	|
|	`RPG++`		|	=		|	There exists no existence beyond the realm of the die. As for the game of my choosing, I am well-versed in all its minutia and errata. My peculiar and unconventional set of rules tend to intimidate the other players.	|
|	`RPG+`		|	=		|	I have scheduled my weekly RPG sessions and have established a well-defined character that I understand intimately, perhaps better than I know myself.	|
|	`RPG`		|	=		|	"Role-Playing? That's just a leisure activity to pass the time on a lazy Saturday afternoon."	|
|	`RPG-`		|	=		|	What a complete and total waste of valuable time!	|
|	`RPG--`		|	=		|	Role-Players are tools of pure evil.	|
|	`RPG---`	|	=		|	I work for T$R.	|
|	`RPG?`		|	=		|	I believe that life itself IS a form of role-playing.	|


BK = Books
------

Furthermore (or conversely), numerous individuals with an affinity for academic pursuits lead lifestyles centered around literature.

|				|			|				|
|:---			|	:---:	|	:---		|
|	`BK++++`	|	=		|	I pride myself on my ability to devour a book on a daily basis, thanks to my possession of library cards from three different states, my account on Z-Library, as well as discount cards from all of the major bookstores. In fact, I have even gone so far as to order books from overseas just to satisfy my insatiable thirst for my favorite author's works	|
|	`BK+++`		|	=		|	Reading is a fundamental part of my daily routine, with a few books being consumed each week as a staple in my literary diet.	|
|	`BK++`		|	=		|	Although my schedule can be quite hectic at times, I always make sure to set aside enough time to immerse myself in at least one new book each month.	|
|	`BK+`		|	=		|	While reading is an activity that brings me great joy, unfortunately, it's not something that I have the opportunity to do very often due to my busy lifestyle.	|
|	`BK`		|	=		|	I like to keep myself up to date on current events by reading the newspaper, as well as indulge in the occasional book.	|
|	`BK-`		|	=		|	In instances where other methods of obtaining information are unavailable, I will resort to reading.	|
|	`BK--`		|	=		|	Through osmosis, I absorb knowledge.	|
|	`BK---`		|	=		|	I did not read the geek code; I had another individual compile my code for me.	|

K = Comics
------

|			|			|			|
|:---		|	:---:	|	:---	|
|	`KD`		|	=		|	Dilbert	|
|	`KX`		|	=		|	XKCD	|
|	`KM`		|	=		|	Manga	|
|	`KM!`		|	=		|	Hentai	|

You may append the code for comics with a modifier from --- to +++ to indicate how much of a fan you are.

LIFESTYLE
======

Geeks, in contrast to nerds, lead a balanced life. They engage in activities that take them beyond the confines of their homes. While they often partake in these activities with fellow geeks, it is important to note that they are not the social pariahs that society deems them to be. The reality is that society is not up to par with our interests and cannot keep up with our pursuits.

MBTI / PERSONALITY
------

Many individuals who identify as geeks have likely taken the Myers & Briggs Type Indicator assessment at some point. If you feel inclined to do so, please feel free to share the results of your assessment with us by providing your corresponding letter code.


R = Residence
------

Tell us about your geeky home.

|			|			|				|
|:---		|	:---:	|	:---		|
|	`R+++`		|	=		|	Nestled in a cave, surrounded by 47 computers, and blessed with an uninterrupted Internet connection, I find solace in my geeky haven situated in close proximity to a Domino's pizza joint.	|
|	`R++`		|	=		|	Preferring the company of my thoughts, I lead a solitary life, venturing out of my abode once a week to purchase necessary groceries and no more than once a month to do my laundry. The surfaces in my living space remain entirely occupied, much like my mind.	|
|	`R+`		|	=		|	Occasionally, I entertain visitors, who share my love for all things geeky. We engage in spirited discussions about the latest trends and topics, and there is a place for everyone to sit.	|
|	`R`			|	=		|	I share my dwelling with other registered geeks who share my same passion for unrestricted intelligence.	|
|	`R-`		|	=		|	Living with individuals who have no understanding of geek culture or television shows catering to my interests is a challenge.	|
|	`R--`		|	=		|	I am happily married or live romantically with a partner.	|
|	`R---`		|	=		|	My living situation is similar to that of Al Bundy's – married with children.	|
|	`R!` 		|	=		|	Circumstances have left me living with my parents, which presents a few obstacles for a geek like me.	|
|	`R?` 		|	=		|	I spend so much of my time in my lab or workplace that it feels more like home than any other place I have lived in, and I'm unsure if I even have a fixed place of residence anymore.	|

RELATIONSHIPS, SEX, AND GENDER
======

While some geeks are able to maintain successful relationships, a significant number struggle in this area. Historically, geeks have had difficulties with sexual experiences, often leading to a lack thereof. As a result, it is crucial for geeks to be open to discussing and quantifying their sexual encounters.

this coding system can indicate the gender of a geek, and it is important to share one's preferred pronouns. These pronouns should always be written in lowercase to avoid any confusion with current or future geekcode, which typically uses capital letters. Finally, adding a modifier can offer insight into one's success with relationships and sexual experiences.

|			|			|				|
|:---		|	:---:	|	:---		|
| 	`*`		|	=		|	I have a sexual inclination that deviates from societal norms.	|
| 	`**`	|	=		|	I am highly skilled in engaging in sexual behavior that is considered taboo.	|
| 	`++++`	|	=		|	I have a handful of children that are evidence of my sexual activity.	|
| 	`+++`	|	=		|	Since I am married, I have the option to have sex with my partner whenever I desire.	|
| 	`++`	|	=		|	I was once labeled as sexually promiscuous without any justification.	|
|	`+`		|	=		|	I have participated in sexual activity with other people.	|
|			|	=		|	To clarify, I have engaged in sexual activity, but only with myself, and not with any another individual.	|
|	`-`		|	=		|	I am choosing not to engage in sexual activity at this time.	|
|	`--`	|	=		|	People do not show any interest in pursuing a romantic relationship with me.	|
|	`---`	|	=		|	Abstaining from sexual activity due to religious or personal beliefs.	|
|	`%`		| 	=		|	I am a member of the SBCA (Sour Bachelor(ette)'s Club of America), a group of single individuals with the motto 'Bitter, but not Desperate'.	|
|	`!`		|	=		|	I do not feel comfortable sharing information about my sexual experiences.	|
|	`>+`	|	=		|	I am actively seeking to gain sexual experience. |

For example:

`he/him+++`